@@ -455,14 +455,14 @@ class PrivKey(KeyPacket):
         sessionkey = self.stokey.derive_key(passphrase)
 
         # attempt to decrypt this key!
-        cipher = Cipher(self.stokey.alg.decalg(sessionkey), modes.CFB(self.stokey.iv), backend=default_backend())
+        cipher = Cipher(self.stokey.alg.decalg(sessionkey), modes.CFB(bytes(self.stokey.iv)), backend=default_backend())
         try:
             decryptor = cipher.decryptor()
 
         except UnsupportedAlgorithm as e:
             raise PGPOpenSSLCipherNotSupported(str(e))
 
-        pt = decryptor.update(self.enc_seckey_material) + decryptor.finalize()
+        pt = decryptor.update(bytes(self.enc_seckey_material)) + decryptor.finalize()
 
         # check the hash to see if we decrypted successfully or not
         if self.stokey.id == 254:
